/*  Project diabar
    
    Copyright  1995. All Rights Reserved.

    SUBSYSTEM:    diabar.exe Application
    FILE:         dbrmdicl.cpp
    AUTHOR:       Free to Anyone


    OVERVIEW
    ========
    Source file for implementation of diabarMDIClient (TMDIClient).      
*/


#include "diabar.h"
#pragma hdrstop

#include <dir.h>

#include "diabrapp.h"
#include "dbrmdich.h"
#include "dbrmdicl.h"
#include "apxprint.h"
#include "apxprev.h"


//{{diabarMDIClient Implementation}}


//
// Build a response table for all messages/commands handled
// by diabarMDIClient derived from TMDIClient.
//
DEFINE_RESPONSE_TABLE1(diabarMDIClient, TMDIClient)
//{{diabarMDIClientRSP_TBL_BEGIN}}
    EV_COMMAND(CM_FILEPRINT, CmFilePrint),
    EV_COMMAND(CM_FILEPRINTERSETUP, CmFilePrintSetup),
    EV_COMMAND(CM_FILEPRINTPREVIEW, CmFilePrintPreview),
    EV_COMMAND_ENABLE(CM_FILEPRINT, CmPrintEnable),
    EV_COMMAND_ENABLE(CM_FILEPRINTERSETUP, CmPrintEnable),
    EV_COMMAND_ENABLE(CM_FILEPRINTPREVIEW, CmPrintEnable),
    EV_WM_DROPFILES,
//{{diabarMDIClientRSP_TBL_END}}
END_RESPONSE_TABLE;


//////////////////////////////////////////////////////////
// diabarMDIClient
// ===========
// Construction/Destruction handling.
diabarMDIClient::diabarMDIClient (TModule* module)
 : TMDIClient (module)
{
    // Change the window's background color
    SetBkgndColor(RGB(0x00, 0x00, 0xa0));

    ChildCount = 0;

    // INSERT>> Your constructor code here.

}


diabarMDIClient::~diabarMDIClient ()
{
    Destroy();

    // INSERT>> Your destructor code here.

}


//////////////////////////////////////////////////////////
// diabarMDIClient
// ===========
// MDIClient site initialization.
void diabarMDIClient::SetupWindow ()
{
    // Default SetUpWindow processing.
    TMDIClient::SetupWindow ();

    // Accept files via drag/drop in the client window.
    DragAcceptFiles(true);
}


//////////////////////////////////////////////////////////
// diabarMDIClient
// ==========
// Menu File Print command
void diabarMDIClient::CmFilePrint ()
{
    //
    // Create Printer object if not already created.
    // 
    diabarApp *theApp = TYPESAFE_DOWNCAST(GetApplication(), diabarApp);
    if (theApp) {
        if (!theApp->Printer)
            theApp->Printer = new TPrinter(GetApplication());

        //
        // Create Printout window and set characteristics.
        //
        APXPrintOut printout(theApp->Printer, Title, GetActiveMDIChild()->GetClientWindow(), true);

        theApp->Printing++;

        //
        // Bring up the Print dialog and print the document.
        //
        theApp->Printer->Print(GetWindowPtr(GetActiveWindow()), printout, true);

        theApp->Printing--;
    }
}


//////////////////////////////////////////////////////////
// diabarMDIClient
// ==========
// Menu File Print Setup command
void diabarMDIClient::CmFilePrintSetup ()
{
    diabarApp *theApp = TYPESAFE_DOWNCAST(GetApplication(), diabarApp);
    if (theApp) {
        if (!theApp->Printer)
            theApp->Printer = new TPrinter(GetApplication());

        //
        // Bring up the Print Setup dialog.
        //
        theApp->Printer->Setup(this);
    }
}


//////////////////////////////////////////////////////////
// diabarMDIClient
// ==========
// Menu File Print Preview command
void diabarMDIClient::CmFilePrintPreview ()
{
    diabarApp *theApp = TYPESAFE_DOWNCAST(GetApplication(), diabarApp);
    if (theApp) {
        if (!theApp->Printer)
            theApp->Printer = new TPrinter(GetApplication());

        theApp->Printing++;

        PreviewWindow *prevW = new PreviewWindow(Parent, theApp->Printer, GetActiveMDIChild()->GetClientWindow(), "Print Preview", new TLayoutWindow(0));
        prevW->Create();

        GetApplication()->BeginModal(GetApplication()->GetMainWindow());

        // We must destroy the preview window explicitly.  Otherwise, the window will not be destroyed until
        // it's parent the MainWindow is destroyed.
        prevW->Destroy();
        delete prevW;

        theApp->Printing--;
    }
}


//////////////////////////////////////////////////////////
// diabarMDIClient
// ==========
// Menu enabler used by Print, Print Setup and Print Preview.
void diabarMDIClient::CmPrintEnable (TCommandEnabler &tce)
{
    if (GetActiveMDIChild()) {
        diabarApp *theApp = TYPESAFE_DOWNCAST(GetApplication(), diabarApp);
        if (theApp) {
            // If we have a Printer already created just test if all is okay.
            // Otherwise create a Printer object and make sure the printer
            // really exists and then delete the Printer object.
            if (!theApp->Printer) {
                theApp->Printer = new TPrinter(GetApplication());
                
                tce.Enable(theApp->Printer->GetSetup().Error == 0);
            } else
                tce.Enable(theApp->Printer->GetSetup().Error == 0);
        }
    } else
        tce.Enable(false);
}


void diabarMDIClient::EvDropFiles (TDropInfo)
{
    Parent->ForwardMessage();
}
